==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebColumnMovingStartEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDetailDescription } from "./WebColumnMovingStartEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnMovingStartEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnMovingStartEventArgsDetailDescriptionMetadata, _super);
    function WebColumnMovingStartEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnMovingStartEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.c(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Source", "ExportedType:WebColumn");
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnMovingStartEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebColumnMovingStartEventArgsDetail", function () { return new WebColumnMovingStartEventArgsDetailDescription(); });
        a.z("WebColumnMovingStartEventArgsDetail", WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.$t = markType(WebColumnMovingStartEventArgsDetailDescriptionMetadata, 'WebColumnMovingStartEventArgsDetailDescriptionMetadata');
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnMovingStartEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebColumnMovingStartEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDetailDescription } from "./WebColumnMovingStartEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnMovingStartEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnMovingStartEventArgsDetailDescriptionMetadata, _super);
    function WebColumnMovingStartEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnMovingStartEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.c(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Source", "ExportedType:WebColumn");
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnMovingStartEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebColumnMovingStartEventArgsDetail", function () { return new WebColumnMovingStartEventArgsDetailDescription(); });
        a.ab("WebColumnMovingStartEventArgsDetail", WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.$t = markType(WebColumnMovingStartEventArgsDetailDescriptionMetadata, 'WebColumnMovingStartEventArgsDetailDescriptionMetadata');
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnMovingStartEventArgsDetailDescriptionMetadata };
